@@ -6,7 +6,7 @@ import sys
 
 from spyderml.lib.asciiarts import banner
 from spyderml.lib.utils import spyder_request, treat_objects, soup_tags, soup_comments, soup_attrs, get_js, \
-    detect_technologies, update_database
+    detect_technologies, update_database, get_all_urls, print_html
 from spyderml.lib.file import open_file
 
 sys.stdin.reconfigure(encoding='utf-8')
@@ -37,6 +37,8 @@ class SpyderHtml:
                         soup_comments(document=html, file=self.args['output'])
                     elif self.args['getjs']:
                         get_js(url=self.args['target'], document=html, file=self.args['output'])
+                    elif self.args['geturls']:
+                        get_all_urls(document=html, file=self.args['output'])
                     else:
                         attr = treat_objects(objects=self.args['attribs'])
                         soup_attrs(document=html, object=attr, file=self.args['output'])
@@ -48,19 +50,23 @@ class SpyderHtml:
             update_database()
 
         else:
-            text = spyder_request(target=self.args['target'])
+            html_document = spyder_request(target=self.args['target'])
             if self.args['tags']:
                 tags = treat_objects(objects=self.args['tags'])
-                soup_tags(document=text, object=tags, file=self.args['output'])
+                soup_tags(document=html_document, object=tags, file=self.args['output'])
             elif self.args['comments']:
-                soup_comments(document=text, file=self.args['output'])
+                soup_comments(document=html_document, file=self.args['output'])
             elif self.args['getjs']:
-                get_js(url=self.args['target'], document=text, file=self.args['output'])
+                get_js(url=self.args['target'], document=html_document, file=self.args['output'])
             elif self.args['techs']:
                 detect_technologies(url=self.args['target'], filepath=self.args['output'])
+            elif self.args['geturls']:
+                get_all_urls(document=html_document, file=self.args['output'])
+            elif self.args['html']:
+                print_html(document=html_document, file = self.args['output'])
             else:
                 attr = treat_objects(objects=self.args['attribs'])
-                soup_attrs(document=text, object=attr, file=self.args['output'])
+                soup_attrs(document=html_document, object=attr, file=self.args['output'])
 
 
 def main():
@@ -74,7 +80,7 @@ def main():
                                                                "http://example.com/index.html")
     group_target.add_argument('-f', '--file', type=str, help="Parameter that defines target URLs")
 
-    group_target.add_argument('--update',help='Flag responsible for updating the database.',
+    group_target.add_argument('--update', help='Flag responsible for updating the database.',
                               default=False, action='store_true')
     group_action.add_argument('--tags', type=str, help="Flag that defines which tags the program will bring")
 
@@ -87,13 +93,20 @@ def main():
                               default=False, action='store_true')
     group_action.add_argument('--techs', help='Flag trying to discover the technologies of the page.',
                               default=False, action='store_true')
+    group_action.add_argument('--geturls', help='This flag takes all the target\'s urls and tries to access them.',
+                              default=False, action='store_true')
+
+    group_action.add_argument('--html', help='This Flag results in all the page\'s html code.',
+                              default=False, action='store_true')
+
     parser.add_argument('-o', '--output', type=str, help="Flag that defines in which file the command output will be "
-                                                        "saved.")
+                                                         "saved.")
 
     args = vars(parser.parse_args())
 
     if not any(args.values()):
         parser.error('No arguments provided.')
+        exit()
 
     sp = SpyderHtml(args)
     sp.run()
